##### master

[![GitHub license](https://img.shields.io/github/license/srounet/pymem.svg)](https://github.com/srounet/Pymem/)
[![Build status](https://ci.appveyor.com/api/projects/status/sfdvrtuh9qa2f3aa/branch/master?svg=true)](https://ci.appveyor.com/project/srounet/pymem/branch/master)
[![codecov](https://codecov.io/gh/srounet/Pymem/branch/master/graph/badge.svg)](https://codecov.io/gh/srounet/Pymem/branch/master)
[![Discord](https://img.shields.io/discord/342944948770963476.svg)](https://discord.gg/xaWNac8)

  
##### x64

[![GitHub license](https://img.shields.io/badge/License-MIT-blue.svg)](https://github.com/srounet/Pymem/blob/x64/LICENSE)
[![Build status](https://ci.appveyor.com/api/projects/status/sfdvrtuh9qa2f3aa/branch/x64?svg=true)](https://ci.appveyor.com/project/srounet/pymem/branch/x64)
[![codecov](https://codecov.io/gh/srounet/Pymem/branch/x64/graph/badge.svg)](https://codecov.io/gh/srounet/Pymem/branch/x64)
[![Discord](https://img.shields.io/discord/342944948770963476.svg)](https://discord.gg/xaWNac8)


Pymem
=====

A python library to manipulate Windows processes.

Documentation
=============
You can find pymem documentation on readthedoc there: http://pymem.readthedocs.io/

Issues And Contributions
========================
Feel free to add issues and make pull-requests :)

Discord Support
===============
For questions and support, join us on discord https://discord.gg/xaWNac8
